Documentation
¶
Overview ¶
Package netinfo provides an i3bar module for network information.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Module ¶
type Module struct {
// contains filtered or unexported fields
}
Module represents a netinfo bar module.
func Interface ¶
Interface constructs an instance of the netinfo module restricted to the specified interface.
func Prefix ¶
Prefix constructs an instance of the netinfo module restricted to interfaces with the given prefix.
func (*Module) Output ¶
Output configures a module to display the output of a user-defined function.
type State ¶
State represents the network state.
func (State) Connected ¶
Connected returns true if connected to a network.
func (State) Connecting ¶
Connecting returns true if a connection is in progress.
func (State) Enabled ¶
Enabled returns true if a network interface is enabled.
func (State) Gone ¶
Gone returns true if a network interface just disappeared..
Source Files
¶
- netinfo.go